@@ -65,23 +65,25 @@ class SequentialBpmnEngine(BpmnEngine):
         return self.invoke_by_event(NoneEvent(ref.group, ref.process_id), init_state, header)[0]
 
     def _handle_action(self, action: Action, state: State, env: Environment) -> List[State]:
+        action, state, env = self.interceptor(action, state, env)
+
         logging.info(action)
 
         # Continue Action
         # ***************
         if isinstance(action, ContinueAction):
-            node = self.interceptor(env.get_node(action.id))
+            node = self.interceptor.intercept_node(env.get_node(action.id))
             assert node is not None, f"no node found with id {action.id}"
 
-            node_ref = NodeRef(env.group, state.reference.process_id, action.id, str(uuid.uuid4()), str(uuid.uuid4()))
+            node_ref = NodeRef(env.group, state.node_ref.process_id, action.id, str(uuid.uuid4()), str(uuid.uuid4()))
             new_state = state.with_reference(node_ref)
 
             # execute all present boundary events in order to register their events
             [self._handle_action(ContinueAction(e.id), state, env) for e in env.get_boundary_events(node.id)]
 
-            [x.before_node_execution(node) for x in self.listeners]
+            [x.before_node_execution(node, new_state) for x in self.listeners]
             new_state, next_actions = node.execute(new_state, env)
-            [x.after_node_execution(node) for x in self.listeners]
+            [x.after_node_execution(node, new_state) for x in self.listeners]
 
             return flatten([self._handle_action(action, new_state, env) for action in next_actions])
 
@@ -108,7 +110,7 @@ class SequentialBpmnEngine(BpmnEngine):
 
             if action.event is not None:
                 # register an event subscription to get ready for an ResumeAction
-                self.event_registry.create_subscription(action.event, state.reference, action.consumable)
+                self.event_registry.create_subscription(action.event, state.node_ref, action.consumable)
                 # return the state as the intermediate result of the process
                 return [state]
 
@@ -117,7 +119,7 @@ class SequentialBpmnEngine(BpmnEngine):
         # Dequeue Action
         # ************
         elif isinstance(action, DequeueAction):
-            self.event_registry.delete_subscription(action.event, state.reference)
+            self.event_registry.delete_subscription(action.event, state.node_ref)
 
             return []
 
