@@ -22,7 +22,7 @@ class InMemoryProcessStore(ProcessStore):
         return self.process_cache[str(ref)] if str(ref) in self.process_cache else None
 
     def write_state(self, state: State):
-        self.state_cache[str(state.reference)] = state
+        self.state_cache[str(state.node_ref)] = state
 
     def read_state(self, ref: NodeRef) -> State:
         return self.state_cache[str(ref)]
