@@ -14,9 +14,6 @@ class UserTask(BpmnNode):
     a User Task, a new task is created in the task list of the user(s) or group(s) assigned to that task.
     """
 
-    def __init__(self, element: dict):
-        super().__init__(element)
-
     # noinspection PyBroadException
     def execute(self, state: State, environment: Environment) -> Tuple[State, Actions]:
         if state.is_reentry:
